# pyexamgen
pyexamgen is a generator which allows easy generation of exams. It uses Mako as
a templating engine and has functionality that allows randomization of both the
content of individual tasks as well as automatic, pseudo-random selection of
specific tasks.  For example, in a quiz you can specify that it should ask k of
a total of n questions; the specific questions will be randomly selected if you
wish.

## License
GNU GPL-3.
